<? 
    include ("../../auth.php"); 
    include ("structures.php");

    if ($structure[profile]) {
	if (!$structure[deny]) $structure[deny]="You dont have Permission to access this page.";
	if (!profile($structure[profile])) die ("<H1>".$structure[deny]."</H1></HTML>");
    }
    
    if (!$structure[no_records_message]) $structure[no_records_message] = "No Records Found.";

    $api = $jffnms->get($structure[object]);
    adm_header($structure[title]);

    if (($action=="view") && ($structure["action_type"]==2)) adm_frame_menu_split($structure["split"],$structure["split_standard"]);

    if (($action=="add") && ($structure[disable_add]!=1)) {

	if ($structure[filter_by_user]) $filter=$auth_user_id; //filter by user

	$actionid=$api->add($filter);

	if ($structure[filter_by_user]) unset($filter); //filter by user

	$action="edit";
    }

    if ($action=="update") {
	foreach($structure["fields"] as $field_name=>$field_data) 
	    if ($field_name) { 
		
		switch ($field_data["type"]) { 
		    case "checkbox" : 	if ($$field_name=="") $$field_name=0; break;
		    case "select"   : 	if (($field_data["params"] > 1) && (is_array($$field_name))) { //size > 1 and array result
					    foreach ($$field_name as $key=>$aux_value) 
						if ($aux_value > 1) {
	    					    if ($key==0)
							$api->update($actionid,array($field_name=>$aux_value));
						    else 
							$api->add($filter,$aux_value);
						}
					    $field_name="";
					}
					break;
		}
		if (($structure[filter_by_user]) && ($field_name==$structure[filter_by_user])) 
		    $$field_name=$auth_user_id; //filter by user

		if ($field_name) $data[$field_name]=is_string($$field_name)?trim($$field_name):$$field_name;
	    }
	//debug($data);
	$api->update($actionid,$data);
	$action="list";
    }

    if ($action=="delete") {
	$api->delete($actionid);
	$action="list";
    }

    $rows = 0;
    $rows += 2;
    $rows += count($structure[fields]);

    if ($structure[show_id]==1) $rows++;
    if ($structure[action_type]==2) $rows++;

    if (isset($structure["filter_field"])) 
	$cant = $api->get(NULL,array($structure["filter_field"]=>$filter));
    else
	$cant = $api->get($filter);

    adm_table_header($structure[title],$init,&$span,$rows,$cant);
    
    if ($cant > 0) $api->slice($init,$span);
    
    std_table_row();
    
    if ($structure[action_type]==2) adm_table_header_cell("Action","center",3);
	else adm_table_header_cell("Action","center",2);

    if ($structure[show_id]==1) adm_table_header_cell("ID");

    foreach ($structure[fields] as $field_data) 
	if ($field_data)
	    switch ($field_data[type]) {
		case "checkbox": adm_table_header_cell($field_data[name],"center"); break;
		case "hidden": break;
		default : adm_table_header_cell($field_data[name]); break;
	    }

    adm_table_row_close();
    
    if ($cant > 0) {
	while ($register = $api->fetch()) {

	    if ($structure[another_id]) $register[id] = $register[$structure[another_id]];

	    if ((($structure[hide_record_one]==0) || ($register[id] > 1)) && //hide record number 1
		(($structure[filter_by_user]=="") || ($register[$structure[filter_by_user]]==$auth_user_id)) //filter by user
	       ) {
	    extract($register);
	    //debug ($register);

	    table_shift_color($table_color);


	    if (($actionid==$id) && ($action=="edit"))  {
		adm_form("update");
		adm_table_row($table_color);

		if ($structure[action_type]==2) adm_table_cell(adm_form_submit(),"center",3);
		    else adm_table_cell(adm_form_submit(),"center",2);

		if ($structure[show_id]==1) adm_table_cell($id);
	    
		foreach ($structure["fields"] as $field_name=>$field_data) {
		    if ($field_name) {
			switch ($field_data["type"]) {
			    case "textbox": adm_table_cell(textbox($field_name,$$field_name,$field_data[size])); break;
			    case "memobox": adm_table_cell(memobox($field_name,$field_data[height],$field_data[width],$$field_name)); break;
			    case "checkbox": adm_table_cell(checkbox($field_name,$$field_name,1),"center"); break;
			    case "select": 
			    	    if (!is_array($field_data["params"])) $field_data["params"] = array();

				    if (!is_array($register[$field_data["params_field"]])) 
					$params_field = array($register[$field_data["params_field"]]);
				    else
					$params_field = $register[$field_data["params_field"]];
				    
				    $aux_param = array_merge(array($field_name,$register[$field_name]),$field_data["params"],$params_field);
				    adm_table_cell(call_user_func_array($field_data["func"],$aux_param)); 
				    break;
		
			    case "colorbox": adm_table_cell(select_color($field_name,$$field_name,1)); break;
			    case "hidden" : echo hidden($field_name,$register[$field_name]); break;
			}
		    }
		}
		adm_table_row_close();
		adm_form_close();
	    } else { 
		adm_table_row($table_color);

		if ($structure[action_type]==2) adm_standard_edit_delete(2,NULL,$structure["split_view_name"]);
		    else adm_standard_edit_delete();
	    
		if ($structure[show_id]==1) adm_table_cell($id);

		foreach ($structure["fields"] as $field_name=>$field_data) {
		    if ($field_name)
			switch ($field_data[type]) {
			    case "textbox": adm_table_cell(htmlspecialchars(substr($$field_name,0,$field_data[size]))); break;
			    case "memobox": adm_table_cell(htmlspecialchars(substr($$field_name,0,$field_data[size]))); break;
			    case "checkbox": adm_table_cell(checkbox($field_name,$$field_name,0),"center"); break;
			    case "select": 

			    	if (!is_array($field_data["params"])) $field_data["params"] = array();
			    	if (!is_array($field_data["view_params"])) $field_data["view_params"] = array();
			
				if (!is_array($register[$field_data["params_field"]])) 
					$params_field = array($register[$field_data["params_field"]]);
				    else
					$params_field = $register[$field_data["params_field"]];

				if ($field_data["view"]) 
				    adm_table_cell(htmlspecialchars(substr($$field_data["view"],0,$field_data["size"]))); 
				else 
				    adm_table_cell(call_user_func_array($field_data["func"],
					array_merge(
					    array($field_name,$register[$field_name]),
					    $field_data["params"],
					    $field_data["view_params"],
					    $params_field))); 
				break;
			    case "colorbox": adm_table_cell(select_color($field_name,$$field_name,0)); break;
			}
		    //debug ($field_data);
		}
		adm_table_row_close();
	    } //if edit
	  }//if skip records
	}//while
    } else  //if cant
	table_row("<br><b>".$structure[no_records_message]."</b>","center",$rows);

    adm_footer();
?>
